@@ -32,9 +32,8 @@ from platformio.package.version import pepver_to_semver
 from platformio.system.prune import calculate_unnecessary_system_data
 
 
-def on_platformio_start(ctx, force, caller):
+def on_platformio_start(ctx, caller):
     app.set_session_var("command_ctx", ctx)
-    app.set_session_var("force_option", force)
     set_caller(caller)
     telemetry.on_command()
 
@@ -126,7 +125,7 @@ class Upgrader:
 
 
 def after_upgrade(ctx):
-    terminal_width, _ = shutil.get_terminal_size()
+    terminal_width = shutil.get_terminal_size().columns
     last_version = app.get_state_item("last_version", "0.0.0")
     if last_version == __version__:
         return
@@ -222,7 +221,7 @@ def check_platformio_upgrade():
     if pepver_to_semver(latest_version) <= pepver_to_semver(__version__):
         return
 
-    terminal_width, _ = shutil.get_terminal_size()
+    terminal_width = shutil.get_terminal_size().columns
 
     click.echo("")
     click.echo("*" * terminal_width)
@@ -267,7 +266,7 @@ def check_prune_system():
     if (unnecessary_size / 1024) < threshold_mb:
         return
 
-    terminal_width, _ = shutil.get_terminal_size()
+    terminal_width = shutil.get_terminal_size().columns
     click.echo()
     click.echo("*" * terminal_width)
     click.secho(
