@@ -14,8 +14,8 @@
 
 # pylint: disable=unused-import
 
-from platformio.device.filters.base import DeviceMonitorFilterBase
-from platformio.device.list import list_serial_ports
+from platformio.device.list.util import list_serial_ports
+from platformio.device.monitor.filters.base import DeviceMonitorFilterBase
 from platformio.fs import to_unix_path
 from platformio.platform.base import PlatformBase
 from platformio.project.config import ProjectConfig
