@@ -23,7 +23,7 @@ class TestDirNotExistsError(UnitTestError, UserSideException):
 
     MESSAGE = (
         "A test folder '{0}' does not exist.\nPlease create 'test' "
-        "directory in the project root and put a test set.\n"
+        "directory in the project root and put a test suite.\n"
         "More details about Unit "
         "Testing: https://docs.platformio.org/en/latest/advanced/"
         "unit-testing/index.html"
